@@ -89,7 +89,7 @@ RollTitle::RollTitle( TQWidget *parent ) : TQLabel( "I", parent )
 	title = " ##### ";
 	titleOffset = 0;
 	setTitle( title );
-	connect( &titleTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( rollTitle() ) );
+	connect( &titleTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( rollTitle() ) );
 	titleTimer.start( 50 );
 }
 
@@ -250,7 +250,7 @@ void CoverFrame::mousePressEvent( TQMouseEvent *e )
 	TQPixmap pix;
 
 	switch ( e->button() ) {
-		case Qt::LeftButton: {
+		case TQt::LeftButton: {
 			if ( imagePath.isEmpty() )
 				break;
 			pix.convertFromImage( TQImage( imagePath ) );
@@ -258,7 +258,7 @@ void CoverFrame::mousePressEvent( TQMouseEvent *e )
 				popup( pix );
 			break;
 		}
-		case Qt::RightButton: {
+		case TQt::RightButton: {
 			TQPopupMenu pop( this );
 			pop.insertItem( i18n("Choose a Cover..."), 1 );
 			pop.insertItem( i18n("Gallery..."), 2 );
@@ -291,7 +291,7 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	hSplit->moveToFirst( panel );
 	hSplit->setResizeMode( panel, TQSplitter::KeepSize );
 
-	vSplit = new TQSplitter( Qt::Vertical, panel );
+	vSplit = new TQSplitter( TQt::Vertical, panel );
 	vSplit->setOpaqueResize( true );
 	TQWidget *vb = new TQWidget( vSplit );
 	TDEToolBar *tb = new TDEToolBar( vb );
@@ -416,7 +416,7 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	layout->addWidget( roller, 0, 1 );
 
 	TDEAccel* accel = new TDEAccel(mainWidget);
-	accel->insert("Delete selected", TQt::Key_Delete, this, TQT_SLOT(slotRemoveSelected()));
+	accel->insert("Delete selected", TQt::Key_Delete, this, TQ_SLOT(slotRemoveSelected()));
 
 	m_isCurrentEntry = UserIcon("playing");
 	m_cdPixmap = TDEGlobal::iconLoader()->loadIcon("application-x-cda", TDEIcon::Small);
@@ -435,28 +435,28 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 
 	loadConfig( TDEGlobal::config() );
 
-	connect(coverFrame, TQT_SIGNAL(changeCurrentCover()), this, TQT_SLOT(chooseCurrentCover()));
-	connect(coverFrame, TQT_SIGNAL(gallery()), this, TQT_SLOT(showGallery()));
-	connect(browserComb, TQT_SIGNAL(urlActivated( const KURL& )), this, TQT_SLOT(setBrowserURL( const KURL& )));
-	connect(browserComb, TQT_SIGNAL(returnPressed( const TQString& )), this, TQT_SLOT(setBrowserURL( const TQString& )));
-	connect(fileBrowser, TQT_SIGNAL(urlEntered( const KURL& )), this, TQT_SLOT(browserURLChanged( const KURL& )));
-	connect(fileBrowser, TQT_SIGNAL(fileSelected(const KFileItem*)), this, TQT_SLOT(fileSelected(const KFileItem*)));
-	connect(m_playlistFilter, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotFindText(const TQString&)));
-	connect( searchBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(resetSearch()) );
-	connect(m_playlistSelector, TQT_SIGNAL(returnPressed(const TQString&)), this, TQT_SLOT(slotNewPlaylistName(const TQString&)));
-	connect(m_playlistSelector, TQT_SIGNAL(activated(int)),this, TQT_SLOT(slotPlaylistActivated(int)));
-	connect(m_list, TQT_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), this, TQT_SLOT(slotDropEvent(TQDropEvent*, TQListViewItem*)));
-	connect(m_list, TQT_SIGNAL(aboutToMove()), this, TQT_SLOT(slotPreDropEvent()));
-	connect(m_list, TQT_SIGNAL(doubleClicked(TQListViewItem*)), this, TQT_SLOT(slotPlayDirect(TQListViewItem*)));
-	connect(m_list, TQT_SIGNAL(returnPressed(TQListViewItem*)), this, TQT_SLOT(slotPlayDirect(TQListViewItem*)));
-	connect(m_list, TQT_SIGNAL(signalCut()), this, TQT_SLOT(slotCut()));
-	connect(m_list, TQT_SIGNAL(signalCopy()), this, TQT_SLOT(slotCopy()));
-	connect(m_list, TQT_SIGNAL(signalPaste()), this, TQT_SLOT(slotPaste()));
-	connect(m_list, TQT_SIGNAL(signalSelectAll()), this, TQT_SLOT(slotSelectAll()));
-	connect(m_list, TQT_SIGNAL(signalPlayItem(TQListViewItem*)), this, TQT_SLOT(slotPlayDirect(TQListViewItem*)));
-	connect(m_list, TQT_SIGNAL(signalPlaylistFromSelected()), this, TQT_SLOT(slotPlaylistFromSelected()));
-	connect(m_list, TQT_SIGNAL(signalAddToQueue(MRL)), this, TQT_SLOT(slotAddToQueue(MRL)));
-	connect(m_list->header(), TQT_SIGNAL(clicked(int)), this, TQT_SLOT(slotSort(int)));
+	connect(coverFrame, TQ_SIGNAL(changeCurrentCover()), this, TQ_SLOT(chooseCurrentCover()));
+	connect(coverFrame, TQ_SIGNAL(gallery()), this, TQ_SLOT(showGallery()));
+	connect(browserComb, TQ_SIGNAL(urlActivated( const KURL& )), this, TQ_SLOT(setBrowserURL( const KURL& )));
+	connect(browserComb, TQ_SIGNAL(returnPressed( const TQString& )), this, TQ_SLOT(setBrowserURL( const TQString& )));
+	connect(fileBrowser, TQ_SIGNAL(urlEntered( const KURL& )), this, TQ_SLOT(browserURLChanged( const KURL& )));
+	connect(fileBrowser, TQ_SIGNAL(fileSelected(const KFileItem*)), this, TQ_SLOT(fileSelected(const KFileItem*)));
+	connect(m_playlistFilter, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotFindText(const TQString&)));
+	connect( searchBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(resetSearch()) );
+	connect(m_playlistSelector, TQ_SIGNAL(returnPressed(const TQString&)), this, TQ_SLOT(slotNewPlaylistName(const TQString&)));
+	connect(m_playlistSelector, TQ_SIGNAL(activated(int)),this, TQ_SLOT(slotPlaylistActivated(int)));
+	connect(m_list, TQ_SIGNAL(dropped(TQDropEvent*, TQListViewItem*)), this, TQ_SLOT(slotDropEvent(TQDropEvent*, TQListViewItem*)));
+	connect(m_list, TQ_SIGNAL(aboutToMove()), this, TQ_SLOT(slotPreDropEvent()));
+	connect(m_list, TQ_SIGNAL(doubleClicked(TQListViewItem*)), this, TQ_SLOT(slotPlayDirect(TQListViewItem*)));
+	connect(m_list, TQ_SIGNAL(returnPressed(TQListViewItem*)), this, TQ_SLOT(slotPlayDirect(TQListViewItem*)));
+	connect(m_list, TQ_SIGNAL(signalCut()), this, TQ_SLOT(slotCut()));
+	connect(m_list, TQ_SIGNAL(signalCopy()), this, TQ_SLOT(slotCopy()));
+	connect(m_list, TQ_SIGNAL(signalPaste()), this, TQ_SLOT(slotPaste()));
+	connect(m_list, TQ_SIGNAL(signalSelectAll()), this, TQ_SLOT(slotSelectAll()));
+	connect(m_list, TQ_SIGNAL(signalPlayItem(TQListViewItem*)), this, TQ_SLOT(slotPlayDirect(TQListViewItem*)));
+	connect(m_list, TQ_SIGNAL(signalPlaylistFromSelected()), this, TQ_SLOT(slotPlaylistFromSelected()));
+	connect(m_list, TQ_SIGNAL(signalAddToQueue(MRL)), this, TQ_SLOT(slotAddToQueue(MRL)));
+	connect(m_list->header(), TQ_SIGNAL(clicked(int)), this, TQ_SLOT(slotSort(int)));
 }
 
 void PlayList::togglePanel()
@@ -478,7 +478,7 @@ bool PlayList::execTarget( const TQString &target )
 {
 	if ( target=="PLAYLIST" ) {
 		emit showMe( this );
-		TQTimer::singleShot( 100, this, TQT_SLOT(startPlaylist()) );
+		TQTimer::singleShot( 100, this, TQ_SLOT(startPlaylist()) );
 		return true;
 	}
 	return false;
@@ -497,19 +497,19 @@ PlayList::~PlayList()
 
 void PlayList::setupActions()
 {
-	m_repeat = new TDEToggleAction(i18n("&Repeat"), 0 , CTRL|Key_E, this, TQT_SLOT(slotRepeat()), actionCollection(),"playlist_repeat");
+	m_repeat = new TDEToggleAction(i18n("&Repeat"), 0 , CTRL|Key_E, this, TQ_SLOT(slotRepeat()), actionCollection(),"playlist_repeat");
 	m_repeat->setStatusText(i18n("Loop playlist"));
-	m_shuffle = new TDEToggleAction(i18n("Sh&uffle"), 0 , CTRL|Key_R, this, TQT_SLOT(slotShuffle()), actionCollection(),"playlist_shuffle");
+	m_shuffle = new TDEToggleAction(i18n("Sh&uffle"), 0 , CTRL|Key_R, this, TQ_SLOT(slotShuffle()), actionCollection(),"playlist_shuffle");
 	m_shuffle->setStatusText(i18n("Play items in random order"));
-	m_autoCover = new TDEToggleAction(i18n("Autodownload covers"), 0 , 0, this, TQT_SLOT(slotAutoCover()), actionCollection(),"playlist_autocover");
+	m_autoCover = new TDEToggleAction(i18n("Autodownload covers"), 0 , 0, this, TQ_SLOT(slotAutoCover()), actionCollection(),"playlist_autocover");
 	m_autoCover->setStatusText(i18n("Automatic dowloading of covers"));
-	m_showPlayer = new TDEToggleAction(i18n("Don't switch to player window"), 0 , 0, this, TQT_SLOT(slotShowPlayer()), actionCollection(),"playlist_showplayer");
+	m_showPlayer = new TDEToggleAction(i18n("Don't switch to player window"), 0 , 0, this, TQ_SLOT(slotShowPlayer()), actionCollection(),"playlist_showplayer");
 	m_showPlayer->setStatusText(i18n("Don't switch automatically to player window"));
-	new TDEAction(i18n("&Clear Current Playlist"), "eraser", 0, this, TQT_SLOT(slotClearList()), actionCollection(), "playlist_clear");
-	new TDEAction(i18n("Ne&w Playlist"), "document-new", 0, this, TQT_SLOT(slotNewList()), actionCollection(), "playlist_new");
-	new TDEAction(i18n("&Import Playlist..."), "project_open", 0, this, TQT_SLOT(slotPlaylistLoad()), actionCollection(), "playlist_load");
-	new TDEAction(i18n("&Save Current Playlist As..."), "document-save-as", 0, this, TQT_SLOT(slotPlaylistSaveAs()), actionCollection(), "playlist_save_as");
-	new TDEAction(i18n("Re&move Current Playlist"), "window-close", 0, this, TQT_SLOT(slotPlaylistRemove()), actionCollection(), "playlist_remove");
+	new TDEAction(i18n("&Clear Current Playlist"), "eraser", 0, this, TQ_SLOT(slotClearList()), actionCollection(), "playlist_clear");
+	new TDEAction(i18n("Ne&w Playlist"), "document-new", 0, this, TQ_SLOT(slotNewList()), actionCollection(), "playlist_new");
+	new TDEAction(i18n("&Import Playlist..."), "project_open", 0, this, TQ_SLOT(slotPlaylistLoad()), actionCollection(), "playlist_load");
+	new TDEAction(i18n("&Save Current Playlist As..."), "document-save-as", 0, this, TQ_SLOT(slotPlaylistSaveAs()), actionCollection(), "playlist_save_as");
+	new TDEAction(i18n("Re&move Current Playlist"), "window-close", 0, this, TQ_SLOT(slotPlaylistRemove()), actionCollection(), "playlist_remove");
 }
 
 void PlayList::slotClearList()
@@ -1618,7 +1618,7 @@ GalleryDialog::GalleryDialog( TQWidget *parent, GoogleFetcher *goog )
 	imageFrame = new TQFrame( hbox );
 	imageFrame->setFixedSize(500,500);
 	setMainWidget(hbox);
-	connect( &next, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotNext()) );
+	connect( &next, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotNext()) );
 	next.start(1000,true);
 }
 
