@@ -58,7 +58,7 @@ class GoogleFetcher;
 
 class GalleryDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	GalleryDialog( TQWidget *parent, GoogleFetcher *goog );
@@ -76,7 +76,7 @@ private:
 
 class RollTitle : public TQLabel
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -102,7 +102,7 @@ private slots:
 
 class CoverFrame : public TQFrame
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -127,7 +127,7 @@ signals:
 
 class PlayList : public KaffeineInput
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -313,7 +313,7 @@ class TQStringList;
 
 class SubtitleChooser : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	SubtitleChooser(TQStringList, TQString, TQWidget *parent=0, const char *name = 0);
@@ -327,7 +327,7 @@ private:
 
 class MovieChooser : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	MovieChooser(TQStringList, TQString, TQWidget *parent=0, const char *name = 0);
