@@ -41,12 +41,12 @@ AudioEditor::AudioEditor( ChannelDesc *chan, TQWidget *parent ) : AudioEditorUI(
 
 	if ( channel->napid==channel->maxapid ) newBtn->setEnabled( false );
 
-	connect( pidList, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(showProp(int)) );
-	connect( upBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(itemUp()) );
-	connect( downBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(itemDown()) );
-	connect( delBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(itemDelete()) );
-	connect( updateBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(itemUpdate()) );
-	connect( newBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(itemNew()) );
+	connect( pidList, TQ_SIGNAL(highlighted(int)), this, TQ_SLOT(showProp(int)) );
+	connect( upBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(itemUp()) );
+	connect( downBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(itemDown()) );
+	connect( delBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(itemDelete()) );
+	connect( updateBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(itemUpdate()) );
+	connect( newBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(itemNew()) );
 }
 
 void AudioEditor::insertItem( int index, bool updt )
