@@ -26,7 +26,7 @@
 
 class AudioEditor : public AudioEditorUI
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 public:
