@@ -2135,10 +2135,10 @@ bool DvbPanel::getChannelList()
 		int order = sort>>1;
 		switch (order){
 			case 1:
-				channelsCb->setSorting ( column, FALSE );
+				channelsCb->setSorting ( column, false );
 				break;
 			case 0:
-				channelsCb->setSorting ( column, TRUE );
+				channelsCb->setSorting ( column, true );
 				break;
 		}
 	}
