@@ -51,7 +51,7 @@ public:
 
 class KEvents : public TQDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
