@@ -32,7 +32,7 @@
 
 class CdListen : public TQObject, public TQThread
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
