@@ -350,15 +350,15 @@ bool InputManager::close()
 void InputManager::add( KaffeineInput *p, const TQPixmap &icon, const TQString &name )
 {
 	mtBar->appendTab( icon, nextId, name );
-	connect( mtBar->tab( nextId ), TQT_SIGNAL(clicked(int)), this, TQT_SLOT(show(int)) );
+	connect( mtBar->tab( nextId ), TQ_SIGNAL(clicked(int)), this, TQ_SLOT(show(int)) );
 	stack->addWidget( p->inputMainWidget(), nextId );
 	plugs.append( new InputPlugin( p, nextId, name ) );
-	connect( p, TQT_SIGNAL(play(const MRL&,KaffeineInput*)), this, TQT_SLOT(play(const MRL&,KaffeineInput*)));
-	connect( p, TQT_SIGNAL(setCurrentPlugin(KaffeineInput*)), this, TQT_SLOT(setCurrentPlugin(KaffeineInput*)));
-	connect( p, TQT_SIGNAL(statusBarMessage(const TQString&)), this, TQT_SLOT(statusBarMessage(const TQString&)));
-	connect( p, TQT_SIGNAL(stop()), this, TQT_SLOT(stop()));
-	connect( p, TQT_SIGNAL(pause()), this, TQT_SLOT(pause()));
-	connect( p, TQT_SIGNAL(showMe(KaffeineInput*)), this, TQT_SLOT(showMe(KaffeineInput*)));
+	connect( p, TQ_SIGNAL(play(const MRL&,KaffeineInput*)), this, TQ_SLOT(play(const MRL&,KaffeineInput*)));
+	connect( p, TQ_SIGNAL(setCurrentPlugin(KaffeineInput*)), this, TQ_SLOT(setCurrentPlugin(KaffeineInput*)));
+	connect( p, TQ_SIGNAL(statusBarMessage(const TQString&)), this, TQ_SLOT(statusBarMessage(const TQString&)));
+	connect( p, TQ_SIGNAL(stop()), this, TQ_SLOT(stop()));
+	connect( p, TQ_SIGNAL(pause()), this, TQ_SLOT(pause()));
+	connect( p, TQ_SIGNAL(showMe(KaffeineInput*)), this, TQ_SLOT(showMe(KaffeineInput*)));
 	if ( !currentPlugin )
 		currentPlugin = plugs.current()->plug;
 	++nextId;
@@ -371,7 +371,7 @@ void InputManager::addPlayerWidget( TQWidget *w, const TQPixmap &icon, const TQS
 {
 	playerWidget = w;
 	mtBar->appendTab( icon, 2, name );
-	connect( mtBar->tab(2), TQT_SIGNAL(clicked(int)), this, TQT_SLOT(show(int)) );
+	connect( mtBar->tab(2), TQ_SIGNAL(clicked(int)), this, TQ_SLOT(show(int)) );
 	stack->addWidget( playerWidget, 2 );
 }
 
@@ -381,12 +381,12 @@ void InputManager::addStartWindow( TQWidget *w, const TQPixmap &icon, const TQSt
 {
 	startWindow = w;
 	mtBar->appendTab( icon, 1, name );
-	connect( mtBar->tab(1), TQT_SIGNAL(clicked(int)), this, TQT_SLOT(show(int)) );
+	connect( mtBar->tab(1), TQ_SIGNAL(clicked(int)), this, TQ_SLOT(show(int)) );
 	stack->addWidget( startWindow, 1 );
 	mtBar->setTab( 1, true );
 	stack->raiseWidget( 1 );
 	oldMainWidget = currentMainWidget = startWindow;
-	connect( (StartWindow*)w, TQT_SIGNAL(execTarget(const TQString&)), this, TQT_SLOT(execTarget(const TQString&)) );
+	connect( (StartWindow*)w, TQ_SIGNAL(execTarget(const TQString&)), this, TQ_SLOT(execTarget(const TQString&)) );
 }
 
 
