@@ -150,7 +150,7 @@ void InstWizard::internalWizard()
 	info << "<br><hr><b>" << i18n("DVD Drive") << "...</b><br>";
 	TDEProcess process;
 	process << "/sbin/hdparm" << "-d" << "/dev/dvd";
-	connect(&process, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)), this, TQT_SLOT(slotStdout(TDEProcess*, char*, int)));
+	connect(&process, TQ_SIGNAL(receivedStdout(TDEProcess*,char*,int)), this, TQ_SLOT(slotStdout(TDEProcess*, char*, int)));
 	process.start(TDEProcess::Block, TDEProcess::Stdout);
 
 	if (stdout.contains('1'))
