@@ -27,12 +27,12 @@
 
 #include <kwizard.h>
 
-class KProcess;
+class TDEProcess;
 
 class InstWizard : private KWizard
 {
-	Q_OBJECT
-  TQ_OBJECT
+	TQ_OBJECT
+  
 public:
 	static void showWizard()
 	{
@@ -51,7 +51,7 @@ private:
 	InstWizard operator=(const InstWizard &);
 
 private slots:
-	void slotStdout(KProcess *, char *, int);
+	void slotStdout(TDEProcess *, char *, int);
 };
 
 #endif /* INSTWIZARD_H */
