@@ -78,7 +78,7 @@ GStreamerPart::GStreamerPart( TQWidget* parentWidget, const char* /*widgetName*/
 
 	kdDebug() << "GStreamerPart: Creating video window" << endl;
 	m_video = new VideoWindow( parentWidget, m_videosink );
-	connect( m_video, TQT_SIGNAL(signalNewFrameSize(const TQSize&)), this, TQT_SIGNAL(signalNewFrameSize(const TQSize&)) );
+	connect( m_video, TQ_SIGNAL(signalNewFrameSize(const TQSize&)), this, TQ_SIGNAL(signalNewFrameSize(const TQSize&)) );
 	m_video->setFocusPolicy( TQWidget::ClickFocus );
 	setWidget( m_video );
 
@@ -92,7 +92,7 @@ GStreamerPart::GStreamerPart( TQWidget* parentWidget, const char* /*widgetName*/
 	m_logoPath = locate( "data", "kaffeine/logo" );
 	kdDebug() << "GStreamerPart: Found logo animation: " << m_logoPath << endl;
 
-	connect( &busTimer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(slotReadBus()) );
+	connect( &busTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotReadBus()) );
 }
 
 
@@ -266,7 +266,7 @@ bool GStreamerPart::openURL(const MRL& mrl)
 		m_playlist.append( m_mrl );
 	}
 
-	TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(slotPlay()));
+	TQTimer::singleShot(0, this, TQ_SLOT(slotPlay()));
 	return true;
 }
 
@@ -504,10 +504,10 @@ void GStreamerPart::slotVideoSettings()
 		g_object_get( G_OBJECT(m_videosink), "brightness", &bright, NULL );
 
 		m_videoSettings = new VideoSettings( hue, sat, contr, bright );
-		connect( m_videoSettings, TQT_SIGNAL(signalNewBrightness(int)), TQT_TQOBJECT(this), TQT_SLOT(slotBrightness(int)) );
-		connect( m_videoSettings, TQT_SIGNAL(signalNewContrast(int)), TQT_TQOBJECT(this), TQT_SLOT(slotContrast(int)) );
-		connect( m_videoSettings, TQT_SIGNAL(signalNewHue(int)), TQT_TQOBJECT(this), TQT_SLOT(slotHue(int)) );
-		connect( m_videoSettings, TQT_SIGNAL(signalNewSaturation(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSaturation(int)) );
+		connect( m_videoSettings, TQ_SIGNAL(signalNewBrightness(int)), this, TQ_SLOT(slotBrightness(int)) );
+		connect( m_videoSettings, TQ_SIGNAL(signalNewContrast(int)), this, TQ_SLOT(slotContrast(int)) );
+		connect( m_videoSettings, TQ_SIGNAL(signalNewHue(int)), this, TQ_SLOT(slotHue(int)) );
+		connect( m_videoSettings, TQ_SIGNAL(signalNewSaturation(int)), this, TQ_SLOT(slotSaturation(int)) );
 	}
 
 	m_videoSettings->show();
@@ -692,43 +692,43 @@ void GStreamerPart::slotPrepareForFullscreen( bool fullscreen )
 
 void GStreamerPart::initActions()
 {
-	new TDEAction(i18n("Toggle Minimal Mode"), 0, 0, this, TQT_SIGNAL(signalToggleMinimalMode()), actionCollection(), "player_minimal_mode");
-	new TDEAction(i18n("Play"), "media-playback-start", 0, TQT_TQOBJECT(this), TQT_SLOT(slotPlay()), actionCollection(), "player_play");
-	new TDEAction(i18n("Pause"), "media-playback-pause", Key_Space, TQT_TQOBJECT(this), TQT_SLOT(slotTogglePause()), actionCollection(), "player_pause");
-	new TDEAction(i18n("Stop"), "media-playback-stop", Key_Backspace, TQT_TQOBJECT(this), TQT_SLOT(slotStop()), actionCollection(), "player_stop");
-	new TDEAction(i18n("&Next"), "media-skip-forward", Key_PageDown, TQT_TQOBJECT(this), TQT_SLOT(slotNext()), actionCollection(), "player_next");
-	new TDEAction(i18n("&Previous"), "media-skip-backward", Key_PageUp, TQT_TQOBJECT(this), TQT_SLOT(slotPrevious()), actionCollection(), "player_previous");
+	new TDEAction(i18n("Toggle Minimal Mode"), 0, 0, this, TQ_SIGNAL(signalToggleMinimalMode()), actionCollection(), "player_minimal_mode");
+	new TDEAction(i18n("Play"), "media-playback-start", 0, this, TQ_SLOT(slotPlay()), actionCollection(), "player_play");
+	new TDEAction(i18n("Pause"), "media-playback-pause", Key_Space, this, TQ_SLOT(slotTogglePause()), actionCollection(), "player_pause");
+	new TDEAction(i18n("Stop"), "media-playback-stop", Key_Backspace, this, TQ_SLOT(slotStop()), actionCollection(), "player_stop");
+	new TDEAction(i18n("&Next"), "media-skip-forward", Key_PageDown, this, TQ_SLOT(slotNext()), actionCollection(), "player_next");
+	new TDEAction(i18n("&Previous"), "media-skip-backward", Key_PageUp, this, TQ_SLOT(slotPrevious()), actionCollection(), "player_previous");
 
 	m_timer = new Timer();
 	new KWidgetAction(m_timer->getSlider(), i18n("Position"), 0, 0, 0, actionCollection(), "player_position");
 	new KWidgetAction((TQWidget*)m_timer->getLabel(), i18n("Playtime"), 0, 0, 0, actionCollection(), "player_playtime");
 
 	m_audioVisual = new TDESelectAction(i18n("Audio &Visualization"), 0, actionCollection(), "audio_visual");
-	connect(m_audioVisual, TQT_SIGNAL(activated(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(slotSetVisualPlugin(const TQString&)));
+	connect(m_audioVisual, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(slotSetVisualPlugin(const TQString&)));
 	m_audioVisualPluginList.prepend("none");
 	m_audioVisual->setItems(m_audioVisualPluginList);
 	m_audioVisual->setCurrentItem(m_audioVisual->items().findIndex(m_visualPluginName));
 
-	new TDEAction(i18n("&Mute"), "player_mute", Key_U, TQT_TQOBJECT(this), TQT_SLOT(slotMute()), actionCollection(), "audio_mute");
-	new TDEAction(i18n("&Auto"), "zoom-fit-best", Key_F5, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioAuto()), actionCollection(), "aspect_auto");
-	new TDEAction(i18n("&4:3"), "zoom-fit-best", Key_F6, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatio4_3()), actionCollection(), "aspect_43");
-	new TDEAction(i18n("A&namorphic"), "zoom-fit-best", Key_F7, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioAnamorphic()), actionCollection(), "aspect_anamorphic");
-	new TDEAction(i18n("&DVB"), "zoom-fit-best", Key_F8, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioDVB()), actionCollection(), "aspect_dvb");
-	new TDEAction(i18n("&Square"), "zoom-fit-best", Key_F9, TQT_TQOBJECT(m_video), TQT_SLOT(slotAspectRatioSquare()), actionCollection(), "aspect_square");
-	new TDEAction(i18n("&Video Settings"), "configure", Key_V, TQT_TQOBJECT(this), TQT_SLOT(slotVideoSettings()), actionCollection(), "video_settings");
-	new TDEAction(i18n("Track &Info"), "application-vnd.tde.info", 0 , TQT_TQOBJECT(this), TQT_SLOT(slotInfo()), actionCollection(), "player_track_info");
+	new TDEAction(i18n("&Mute"), "player_mute", Key_U, this, TQ_SLOT(slotMute()), actionCollection(), "audio_mute");
+	new TDEAction(i18n("&Auto"), "zoom-fit-best", Key_F5, m_video, TQ_SLOT(slotAspectRatioAuto()), actionCollection(), "aspect_auto");
+	new TDEAction(i18n("&4:3"), "zoom-fit-best", Key_F6, m_video, TQ_SLOT(slotAspectRatio4_3()), actionCollection(), "aspect_43");
+	new TDEAction(i18n("A&namorphic"), "zoom-fit-best", Key_F7, m_video, TQ_SLOT(slotAspectRatioAnamorphic()), actionCollection(), "aspect_anamorphic");
+	new TDEAction(i18n("&DVB"), "zoom-fit-best", Key_F8, m_video, TQ_SLOT(slotAspectRatioDVB()), actionCollection(), "aspect_dvb");
+	new TDEAction(i18n("&Square"), "zoom-fit-best", Key_F9, m_video, TQ_SLOT(slotAspectRatioSquare()), actionCollection(), "aspect_square");
+	new TDEAction(i18n("&Video Settings"), "configure", Key_V, this, TQ_SLOT(slotVideoSettings()), actionCollection(), "video_settings");
+	new TDEAction(i18n("Track &Info"), "application-vnd.tde.info", 0 , this, TQ_SLOT(slotInfo()), actionCollection(), "player_track_info");
 
-	m_volume = new TQSlider(Qt::Horizontal, 0);
+	m_volume = new TQSlider(TQt::Horizontal, 0);
 	TQToolTip::add(m_volume, i18n("Volume"));
 	m_volume->setRange(0, 100);
 	m_volume->setSteps(1, 5);
 	m_volume->setFixedWidth(75);
-	connect(m_volume, TQT_SIGNAL(valueChanged(int)), TQT_TQOBJECT(this), TQT_SLOT(slotVolume(int)));
+	connect(m_volume, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotVolume(int)));
 	slotSetVolume(m_savedVolume);
 	new KWidgetAction(m_volume, i18n("Volume"), 0, 0, 0, actionCollection(), "audio_volume");
-	new TDEAction(i18n("&GStreamer Engine Parameters"), "edit", 0, TQT_TQOBJECT(this), TQT_SLOT(slotConfigDialog()), actionCollection(), "settings_gst_parameter");
+	new TDEAction(i18n("&GStreamer Engine Parameters"), "edit", 0, this, TQ_SLOT(slotConfigDialog()), actionCollection(), "settings_gst_parameter");
 
-	connect(m_video, TQT_SIGNAL(signalRightClick(const TQPoint&)), TQT_TQOBJECT(this), TQT_SLOT(slotContextMenu(const TQPoint&)));
+	connect(m_video, TQ_SIGNAL(signalRightClick(const TQPoint&)), this, TQ_SLOT(slotContextMenu(const TQPoint&)));
 }
 
 
@@ -995,7 +995,7 @@ void GStreamerPart::slotReadBus()
 			if (m_url != m_logoPath) {
 				errorMessage = error->message;
 				errorDetails = debug;
-				TQTimer::singleShot( 0, TQT_TQOBJECT(this), TQT_SLOT(slotEngineError()) );
+				TQTimer::singleShot( 0, this, TQ_SLOT(slotEngineError()) );
 			}
 			g_error_free( error );
 			g_free( debug );
