@@ -37,7 +37,7 @@
 
 class GStreamerPart : public KaffeinePart
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	GStreamerPart( TQWidget*, const char*, TQObject*, const char*, const TQStringList& );
