@@ -41,11 +41,11 @@
 Timer::Timer() : TQObject()
 {
 	m_label = new TQLabel( "0:00 / 0:00", 0 );
-	m_slider = new TQSlider( Qt::Horizontal, 0 );
+	m_slider = new TQSlider( TQt::Horizontal, 0 );
 	m_slider->setMinValue( 0 );
 	m_slider->setEnabled( false );
 
-	connect( &updateTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotUpdate()) );
+	connect( &updateTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotUpdate()) );
 
 	m_pos = GST_CLOCK_TIME_NONE;
 	m_len = GST_CLOCK_TIME_NONE;
@@ -53,8 +53,8 @@ Timer::Timer() : TQObject()
 	m_play = NULL;
 	seeking = false;
 
-	connect( m_slider, TQT_SIGNAL(sliderPressed()), this, TQT_SLOT(slotSeekStart()) );
-	connect( m_slider, TQT_SIGNAL(sliderReleased()), this, TQT_SLOT(slotSeek()) );
+	connect( m_slider, TQ_SIGNAL(sliderPressed()), this, TQ_SLOT(slotSeekStart()) );
+	connect( m_slider, TQ_SIGNAL(sliderReleased()), this, TQ_SLOT(slotSeek()) );
 }
 
 
