@@ -58,7 +58,7 @@ VideoWindow::VideoWindow( TQWidget *parent, GstElement *_element )
 	setPaletteBackgroundColor(TQColor(0,0,0)); //black
 	setUpdatesEnabled(false);
 
-	connect( &m_mouseHideTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotHideMouse()) );
+	connect( &m_mouseHideTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotHideMouse()) );
 }
 
 
@@ -115,7 +115,7 @@ void VideoWindow::paintEvent(TQPaintEvent */*event*/)
 
 void VideoWindow::mousePressEvent(TQMouseEvent* mev)
 {
-	if ( mev->button()==Qt::RightButton ) {
+	if ( mev->button()==TQt::RightButton ) {
 		emit signalRightClick( mev->globalPos() );
 		mev->accept();
 	}
