@@ -35,7 +35,7 @@
 
 class VideoWindow : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
