@@ -35,9 +35,9 @@
  * @author Jürgen Kofler
  */
 
-class KDE_EXPORT KaffeinePart : public KParts::ReadOnlyPart
+class TDE_EXPORT KaffeinePart : public KParts::ReadOnlyPart
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KaffeinePart(TQObject* parent, const char* name);
