@@ -50,7 +50,7 @@ FilterDialog::FilterDialog(const TQStringList& audioFilters, const TQStringList&
   TQCheckBox* useAudioFiltersCB = new TQCheckBox( audioPage );
   useAudioFiltersCB->setText( i18n("Enable audio filters") );
   useAudioFiltersCB->setChecked( true );
-  connect( useAudioFiltersCB, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotUseAudioFilters(bool)));
+  connect( useAudioFiltersCB, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotUseAudioFilters(bool)));
 
   audioGrid->addMultiCellWidget( useAudioFiltersCB, 0, 0, 0, 2 );
   
@@ -58,9 +58,9 @@ FilterDialog::FilterDialog(const TQStringList& audioFilters, const TQStringList&
   m_audioFilterCombo->insertStringList( audioFilters );
 
   m_addAudioButton = new KPushButton( i18n("Add Filter"), audioPage );
-  connect( m_addAudioButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAddAudioClicked() ));
+  connect( m_addAudioButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddAudioClicked() ));
   m_removeAudioButton = new KPushButton( i18n("Remove All Filters"), audioPage );
-  connect( m_removeAudioButton, TQT_SIGNAL( clicked() ), this, TQT_SIGNAL( signalRemoveAllAudioFilters() ));
+  connect( m_removeAudioButton, TQ_SIGNAL( clicked() ), this, TQ_SIGNAL( signalRemoveAllAudioFilters() ));
 
   audioGrid->addWidget( m_audioFilterCombo, 1, 0 );
   audioGrid->addWidget( m_removeAudioButton, 1, 2 );
@@ -83,7 +83,7 @@ FilterDialog::FilterDialog(const TQStringList& audioFilters, const TQStringList&
   TQCheckBox* useVideoFiltersCB = new TQCheckBox( videoPage );
   useVideoFiltersCB->setText( i18n("Enable video filters") );
   useVideoFiltersCB->setChecked( true );
-  connect( useVideoFiltersCB, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotUseVideoFilters(bool)));
+  connect( useVideoFiltersCB, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotUseVideoFilters(bool)));
 
   videoGrid->addMultiCellWidget( useVideoFiltersCB, 0, 0, 0, 2 );
   
@@ -91,9 +91,9 @@ FilterDialog::FilterDialog(const TQStringList& audioFilters, const TQStringList&
   m_videoFilterCombo->insertStringList( videoFilters );
 
   m_addVideoButton = new KPushButton( i18n("Add Filter"), videoPage );
-  connect( m_addVideoButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAddVideoClicked() ));
+  connect( m_addVideoButton, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotAddVideoClicked() ));
   m_removeVideoButton = new KPushButton( i18n("Remove All Filters"), videoPage );
-  connect( m_removeVideoButton, TQT_SIGNAL( clicked() ), this, TQT_SIGNAL( signalRemoveAllVideoFilters() ));
+  connect( m_removeVideoButton, TQ_SIGNAL( clicked() ), this, TQ_SIGNAL( signalRemoveAllVideoFilters() ));
 
   videoGrid->addWidget( m_videoFilterCombo, 1, 0 );
   videoGrid->addWidget( m_removeVideoButton, 1, 2 );
