@@ -26,11 +26,11 @@
 #include "positionslider.moc"
 
 
-PositionSlider::PositionSlider(Qt::Orientation o, TQWidget *parent, const char* name) :
+PositionSlider::PositionSlider(TQt::Orientation o, TQWidget *parent, const char* name) :
            TQSlider(o, parent, name), m_userChange(false)
 {
-	connect(this, TQT_SIGNAL(sliderPressed()), this ,TQT_SLOT(slotSliderPressed()));
-	connect(this, TQT_SIGNAL(sliderReleased()), this, TQT_SLOT(slotSliderReleased()));
+	connect(this, TQ_SIGNAL(sliderPressed()), this ,TQ_SLOT(slotSliderPressed()));
+	connect(this, TQ_SIGNAL(sliderReleased()), this, TQ_SLOT(slotSliderReleased()));
 	installEventFilter(this);
 }
 
@@ -93,7 +93,7 @@ bool PositionSlider::eventFilter(TQObject *obj, TQEvent *ev)
 		TQMouseEvent *e = (TQMouseEvent *)ev;
 		TQRect r = sliderRect();
 
-		if( r.contains( e->pos() ) || e->button() != Qt::LeftButton )
+		if( r.contains( e->pos() ) || e->button() != TQt::LeftButton )
 			return false;
 
 		int range = maxValue() - minValue();
