@@ -82,7 +82,7 @@ PostFilter::PostFilter(const TQString& name, xine_t* engine, xine_audio_port_t*
                 PostFilterParameterCombo(m_xinePostParameter->name, m_xinePostParameter->offset,
                                           *(int*)(m_data+m_xinePostParameter->offset),
                                           m_xinePostParameter->enum_values, m_groupBox );
-              connect(parameter, TQT_SIGNAL(signalIntValue(int, int)), this, TQT_SLOT(slotApplyIntValue(int, int)));
+              connect(parameter, TQ_SIGNAL(signalIntValue(int, int)), this, TQ_SLOT(slotApplyIntValue(int, int)));
               m_parameterList.append(parameter);
 
               grid->addWidget(parameter->getWidget(), row, 0);
@@ -95,7 +95,7 @@ PostFilter::PostFilter(const TQString& name, xine_t* engine, xine_audio_port_t*
                                         (int)m_xinePostParameter->range_min, (int)m_xinePostParameter->range_max,
                                         m_groupBox);
 
-              connect(parameter, TQT_SIGNAL( signalIntValue(int, int)), this, TQT_SLOT( slotApplyIntValue(int, int)));
+              connect(parameter, TQ_SIGNAL( signalIntValue(int, int)), this, TQ_SLOT( slotApplyIntValue(int, int)));
               m_parameterList.append(parameter);
 
               grid->addWidget(parameter->getWidget(), row, 0);
@@ -110,7 +110,7 @@ PostFilter::PostFilter(const TQString& name, xine_t* engine, xine_audio_port_t*
                                          (double)m_xinePostParameter->range_min, (double)m_xinePostParameter->range_max,
                                          m_groupBox);
 
-            connect(parameter, TQT_SIGNAL(signalDoubleValue(int, double)), this, TQT_SLOT(slotApplyDoubleValue(int, double)));
+            connect(parameter, TQ_SIGNAL(signalDoubleValue(int, double)), this, TQ_SLOT(slotApplyDoubleValue(int, double)));
             m_parameterList.append(parameter);
 
             grid->addWidget(parameter->getWidget(), row, 0);
@@ -123,7 +123,7 @@ PostFilter::PostFilter(const TQString& name, xine_t* engine, xine_audio_port_t*
                                        (char*)(m_data+m_xinePostParameter->offset), m_xinePostParameter->size,
                                        m_groupBox);
 
-            connect( parameter, TQT_SIGNAL(signalCharValue(int, const TQString&)), this, TQT_SLOT(slotApplyCharValue(int, const TQString&)));
+            connect( parameter, TQ_SIGNAL(signalCharValue(int, const TQString&)), this, TQ_SLOT(slotApplyCharValue(int, const TQString&)));
             m_parameterList.append(parameter);
 
             grid->addWidget(parameter->getWidget(), row, 0);
@@ -137,7 +137,7 @@ PostFilter::PostFilter(const TQString& name, xine_t* engine, xine_audio_port_t*
               PostFilterParameterBool(m_xinePostParameter->name, m_xinePostParameter->offset,
                                        (bool) *(int*)(m_data+m_xinePostParameter->offset), m_groupBox);
 
-            connect(parameter, TQT_SIGNAL(signalIntValue(int, int)), this, TQT_SLOT(slotApplyIntValue(int, int)));
+            connect(parameter, TQ_SIGNAL(signalIntValue(int, int)), this, TQ_SLOT(slotApplyIntValue(int, int)));
             m_parameterList.append(parameter);
 
             grid->addWidget(parameter->getWidget(), row, 0);
@@ -158,14 +158,14 @@ PostFilter::PostFilter(const TQString& name, xine_t* engine, xine_audio_port_t*
     row++;
     KPushButton* deleteButton = new KPushButton(i18n("Delete Filter"), m_groupBox);
     deleteButton->setSizePolicy (TQSizePolicy (TQSizePolicy::Minimum, TQSizePolicy::Fixed));
-    connect(deleteButton, TQT_SIGNAL(clicked()), this, TQT_SLOT( slotDeletePressed()));
+    connect(deleteButton, TQ_SIGNAL(clicked()), this, TQ_SLOT( slotDeletePressed()));
     grid->addWidget(deleteButton, row, 0);
 
     if(inputAPI)
     {
       KPushButton* helpButton = new KPushButton(i18n("Help"), m_groupBox);
       helpButton->setSizePolicy(TQSizePolicy (TQSizePolicy::Minimum, TQSizePolicy::Fixed));
-      connect(helpButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotHelpPressed()));
+      connect(helpButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotHelpPressed()));
       grid->addWidget(helpButton, row, 1);
     }
 
@@ -334,7 +334,7 @@ PostFilterParameterInt::PostFilterParameterInt(const TQString& name, int offset,
 {
   m_numInput = new KIntNumInput(value, parent);
   m_numInput->setRange( min, max, 1, false);
-  connect(m_numInput, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotIntValue(int)));
+  connect(m_numInput, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotIntValue(int)));
 }
 
 PostFilterParameterDouble::PostFilterParameterDouble(const TQString& name, int offset, double value, double min, double max, TQWidget* parent)
@@ -343,7 +343,7 @@ PostFilterParameterDouble::PostFilterParameterDouble(const TQString& name, int o
   m_numInput = new KDoubleNumInput(parent);
   m_numInput->setValue(value);
   m_numInput->setRange(min, max, 0.01, false);
-  connect(m_numInput, TQT_SIGNAL(valueChanged( double)), this, TQT_SLOT(slotDoubleValue( double)));
+  connect(m_numInput, TQ_SIGNAL(valueChanged( double)), this, TQ_SLOT(slotDoubleValue( double)));
 }
 
 PostFilterParameterChar::PostFilterParameterChar(const TQString& name, int offset, char *value, int size, TQWidget* parent)
@@ -351,7 +351,7 @@ PostFilterParameterChar::PostFilterParameterChar(const TQString& name, int offse
 {
   m_charInput = new KLineEdit(value, parent);
   m_charInput->setMaxLength(size);
-  connect(m_charInput, TQT_SIGNAL(returnPressed(const TQString&)), this, TQT_SLOT(slotCharValue(const TQString&)));
+  connect(m_charInput, TQ_SIGNAL(returnPressed(const TQString&)), this, TQ_SLOT(slotCharValue(const TQString&)));
 }
 
 PostFilterParameterCombo::PostFilterParameterCombo(const TQString& name, int offset, int value, char **enums, TQWidget* parent)
@@ -363,7 +363,7 @@ PostFilterParameterCombo::PostFilterParameterCombo(const TQString& name, int off
     m_comboBox->insertItem(enums[i]);
   }
   m_comboBox->setCurrentItem(value);
-  connect(m_comboBox, TQT_SIGNAL( activated(int)), this, TQT_SLOT( slotIntValue(int)));
+  connect(m_comboBox, TQ_SIGNAL( activated(int)), this, TQ_SLOT( slotIntValue(int)));
 }
 
 PostFilterParameterBool::PostFilterParameterBool(const TQString& name, int offset, bool value, TQWidget* parent)
@@ -371,7 +371,7 @@ PostFilterParameterBool::PostFilterParameterBool(const TQString& name, int offse
 {
   m_checkBox = new TQCheckBox(parent);
   m_checkBox->setChecked(value);
-  connect(m_checkBox, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotBoolValue( bool)));
+  connect(m_checkBox, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotBoolValue( bool)));
 }
 
 PostFilterHelp::PostFilterHelp(TQWidget *parent, const char *name, const TQString& text)
